==============
Biblion README
==============

Biblion was the eldarion.com blog which we've extracted and open sourced. It
is currently positioned as being used for site/project blogs such as
eldarion.com and pinaxproject.com. We intend for this app to replace the
internal Pinax blog app once we've made it feature complete.


Current features include:

 * support for multiple channels (e.g. technical vs business)
 * use of Creole as markup format
 * Atom feeds
 * previewing of blog posts before publishing
 * optional ability to announce new posts on twitter
